@@ -1,4 +1,8 @@
+import os
 import asyncio
+import sys
+import traceback
+
 from wizwalker import XYZ, ClientHandler
 from wizwalker import Keycode
 from loguru import logger
@@ -9,6 +13,7 @@ from wizwalker.memory import Window
 handleQuestCollection = True
 is_tab = '\t'.__eq__
 
+cur_path = os.path.dirname(__file__)
 
 @logger.catch()
 async def go_through_dialog(p):
@@ -671,7 +676,7 @@ async def goToNewWorld(p, destinationWorld):
     return bigStackDestinations
 
 async def parseFile(fileName, worldName):
-    file = open(fileName, "r")
+    file = open(f"{cur_path}/{fileName}", "r")
 
     lines = file.readlines()
     start = 'WORLD - ' + worldName + '\n'
@@ -963,19 +968,48 @@ async def goToDestination(p, destinationZone, p1WorldName, bigStackDestinations,
                     await teleportToInteractiveTeleportIfAvailable(p, zone, zoneTo, interactiveTeleportersOriginal)
 
 
+
+
+@logger.catch()
+async def toZoneDisplayName(clients, destinationZoneDisplay):
+    file = open(f"{cur_path}/{'traversalData/displayZones.txt'}", "r")
+    lines = file.readlines()
+
+    destinationZone = ''
+    lines = iter(lines)
+    for q, s in enumerate(lines):
+        s = s.split(';')
+
+        # substring match instead of equality - it is acceptable for users to guess a partial zone name
+        if destinationZoneDisplay in s[2].strip():
+            destinationZone = s[1]
+            break
+
+    if destinationZone != '':
+        zoneChange = await toZone(clients, destinationZone)
+        return zoneChange
+    else:
+        logger.error('Given zone either does not exist, is not valid, or was spelled incorrectly.')
+        return 1
+
+
 @logger.catch()
 async def toZone(clients, destinationZone):
     currentZone = await clients[0].zone_name()
     worldName = currentZone.split('/', 1)[0]
 
-    objectLines = await parseFile("traversalData/objectLocations.txt", worldName)
     interactiveTeleportersOriginal = await parseFile("traversalData/interactiveTeleporters.txt", worldName)
-    uniqueObjectLocationsOriginal = await parseFile("traversalData/uniqueObjectLocations.txt", worldName)
     bigStackDestinations = await createStack(worldName)
 
-    await asyncio.gather(*[goToDestination(p, destinationZone, worldName, bigStackDestinations, interactiveTeleportersOriginal) for p in clients])
+    try:
+        await asyncio.gather(*[goToDestination(p, destinationZone, worldName, bigStackDestinations, interactiveTeleportersOriginal) for p in clients])
+        logger.info(f'reached destination zone: {destinationZone}.')
+        return 0
+    except:
+        print(traceback.print_exc())
+        return 1
+
 
-    logger.info(f'reached destination zone: {destinationZone}.')
 
 potion_ui_buy = [
     "fillallpotions",
@@ -987,6 +1021,8 @@ potion_ui_buy = [
     "exit"
 ]
 
+
+
 # Credit to Notfaj and Slackaduts for the majority of this function from UniversalBotSF
 @logger.catch()
 async def refillPotions(clients):
@@ -1053,7 +1089,7 @@ async def main(clientHandler):
 
     
     try:
-        await toZone(clients, 'WizardCity/WC_Streets/WC_OldeTown')
+        await toZoneDisplayName(clients, 'golem court')
     finally:
         logger.info('Script complete')
 
